﻿using System;
using System.Linq;
using System.Threading.Tasks;
using ELTE.TicTacToeGame.Persistence;
using ELTE.TicTacToeGame.Windows.Persistence;
using Windows.Storage;
using Xamarin.Forms;

[assembly: Dependency(typeof(WindowsFilePersistence))]
namespace ELTE.TicTacToeGame.Windows.Persistence
{
    /// <summary>
    /// Tic-Tac-Toe adatelérés megvalósítása Windows platformra.
    /// </summary>
    public class WindowsFilePersistence : IPersistence
    {
        /// <summary>
        /// Fájl betöltése.
        /// </summary>
        /// <param name="path">Elérési útvonal.</param>
        /// <returns>A beolvasott mezőértékek.</returns>
        public async Task<Player[]> LoadAsync(String path)
        {
            try
            {
                // fájl megnyitása a lokális könyvtárban (aszinkron módon)
                StorageFile file = await ApplicationData.Current.LocalFolder.GetFileAsync(path);

                // tartalom beolvasása (aszinkron módon)
                String text = await FileIO.ReadTextAsync(file);

                return text.Split().Select(number => (Player)Int32.Parse(number)).ToArray();
            }
            catch
            {
                throw new DataException("Sikertelen betöltés.");
            }
        }

        /// <summary>
        /// Fájl mentése.
        /// </summary>
        /// <param name="path">Elérési útvonal.</param>
        /// <param name="values">A mezőértékek.</param>
        public async Task SaveAsync(String path, Player[] values)
        {
            try
            {
                // fájl létrehozása/megnyitása a lokális könyvtárban (aszinkron módon)
                StorageFile file = await ApplicationData.Current.LocalFolder.CreateFileAsync(path, CreationCollisionOption.ReplaceExisting);

                String text = values.Select(value => ((Int32)value).ToString()).Aggregate((value1, value2) => value1 + " " + value2);

                // tartalom kiírása (aszinkron módon)
                await FileIO.WriteTextAsync(file, text);
            }
            catch
            {
                throw new DataException("Sikertelen mentés.");
            }
        }
    }
}